from imonke import iMonkeRequest, iMonkeHandler

request = iMonkeRequest.requests()
url = iMonkeHandler.iMonkeUrl()
json = iMonkeHandler.json()

me_endpoint = url + "me/"
user_endpoint = url + "user/"
auth_endpoint = url + "auth/"


def create_user(email, password, nick, bio=None):

    # Creates a user profile

    headers = {"email": email,
                "nick": nick,
                "password": password}

    general_error = "Please include all params (email, nick, password)"
    bio_warning = "You may include a bio as well"

    if not bio:
        iMonkeHandler.raise_warning(bio_warning)
        pass
    else:
        headers['bio'] = bio

    try:
        data = request.post(user_endpoint, data=json.dumps(headers))
        return data.json()
    except Exception as Error:
        raise Error


def get_me(bearer):
    header = {"Authorization": "Bearer " + bearer}
    try:
        data = request.get(me_endpoint, headers=header)
        return data.json()
    except Exception as Error:
        raise Error


def auth(email, password=None, secret=None):

    general_error = "You must provide a secret or a password"
    gen_error_2 = "Only password OR secret please"

    if not secret and not password:
        iMonkeHandler.raise_warning(general_error)
    else:
        pass
    header = {"email": email, }
    if secret:
        header['secret'] = secret

    if password:
        header['password'] = password

    if password and secret:
        iMonkeHandler.raise_warning(gen_error_2)

    try:
        data = request.post(auth_endpoint, json.dumps(header))
        return data.json()
    except Exception as Error:
        raise Error



from imonke import iMonkeHandler, iMonkeRequest


url = iMonkeHandler.iMonkeUrl()
user_endpoint = url + "user/"
user_by_id_endpoint = user_endpoint + "id/"
user_by_nick_endpoint = user_endpoint + "nick/"
request = iMonkeRequest.requests()

def user_by_id(user_id, bearer=None, basic=None):

    # Gets a users information based on their id

    general_error = "Please include either a Basic Auth or a Bearer"

    header = iMonkeHandler.headers(bearer, basic)
    if not header:
        iMonkeHandler.raise_warning(general_error)

    try:
        data = request.get(user_by_id_endpoint + user_id, headers=header)
        return data.json()
    except Exception as Error:
        raise Error


def user_by_nick(nick, bearer=None, basic=None):

    # Gets a users information based on their nick

    general_error = "Please include either a Basic Auth or a Bearer"

    header = iMonkeHandler.headers(bearer, basic)
    if not header:
        iMonkeHandler.raise_warning(general_error)

    try:
        data = request.get(user_by_nick_endpoint + nick, headers=header)
        return data.json()
    except Exception as Error:
        raise Error


def report_user(user_id, reason, bearer=None, basic=None):

    # Reports a user

    general_error = "Please include either a Basic Auth or a Bearer"

    header = iMonkeHandler.headers(bearer, basic)
    if not header:
        iMonkeHandler.raise_warning(general_error)

    data = {"reason": reason}

    try:
        data = request.put(user_by_id_endpoint + user_id + "reports/", headers=header, data=data)
        return data.json()
    except Exception as Error:
        raise Error



from colorama import Style, Fore
import json as JSON

def iMonkeUrl():
    return "http://imonke.gastrodon.io/"

def raise_warning(args):
    message = Fore.YELLOW + "Warning: " + args + Style.RESET_ALL
    print(message)
    return

def headers(bearer=None, basic=None):
    header = {}
    if basic:
        header["Authorization"] = "Basic " + basic
    if bearer:
        header["Authorization"] = "Bearer " + bearer
    return header

def json():
    # Returns a json object
    return JSON


import requests as REQUESTS

def get_post_points(self):
    # Returns a list of post_points
    post_points = ["POST/auth/", "POST/content/", "POST/user/"]
    return post_points

def get_get_points():
    # Returns a list of get_points

    get_points = ["GET/check/email/<email>/", "GET/check/nick/<nick>/",
                      "GET/content/<id>/", "GET/feed/all", "GET/me/",
                      "GET/user/id/<id>/", "GET/user/nick/<nick>/"]
    return get_points

def get_put_points():
    # Returns a list of put_points
    put_points = ["PUT/user/id/<id>/reports", ]
    return put_points

def requests():
    # Returns a requests object
    return REQUESTS


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="imonke",
    version="0.1.1",
    author="Tobi",
    author_email="tobiisdumb@gmail.com",
    description="a iMonke api wrapper",
    long_description=long_description,
    license = "unlicense",
    long_description_content_type="text/markdown",
    url="https://github.com/TobiisDumb/iMonke",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules = ["requests", "colorama"]
)


from imonke import iMonkeRequest, iMonkeHandler

request = iMonkeRequest.requests()
json = iMonkeHandler.json()
url = iMonkeHandler.iMonkeUrl()
content_endpoint = url + "content/"
feed_all_endpoint = url + "feed/all/"


def post_by_id(post_id, bearer=None, basic=None):
    # Get a posts information by its id

    general_error = "Please include either a Basic Auth or a Bearer"

    header = iMonkeHandler.headers(bearer, basic)
    if not header:
        iMonkeHandler.raise_warning(general_error)

    try:
        data = request.get(content_endpoint + post_id, headers=header)
        return data.json()
    except Exception as Error:
        raise Error

def post(bearer, mime, content, nsfw=False, featureable=False, tags=list):

    data = {"mime": mime,
            "nsfw": nsfw,
            "featurable": featureable,
            "tags": tags}

    payload = {'json': json.dumps(data)}

    files = [('file', content)]

    headers_ = {
        'Authorization': 'Bearer ' + bearer
    }

    try:
        data = request.post(content_endpoint, headers=headers_, data=payload, files=files)
        return data.json()
    except Exception as Error:
        raise Error


def feed_all(bearer=None, basic=None, query=None):
    # Get a posts information by its id

    url = feed_all_endpoint

    if not query:
        query = ""
    else:
        query = query

    general_error = "Please include either a Basic Auth or a Bearer"

    header = iMonkeHandler.headers(bearer, basic)
    if not header:
        iMonkeHandler.raise_warning(general_error)

    try:
        data = request.get(url + query, headers=header)
        return data.json()
    except Exception as Error:
        raise Error



from imonke import iMonkeRequest, iMonkeHandler

request = iMonkeRequest.requests()
imonke_url = iMonkeHandler.iMonkeUrl()

url = imonke_url
check_email_endpoint = url + "/check/email/"
check_nick_endpoint = url + "/check/nick/"

def check_email(email):
    # Checks if an email is available
    try:
        data = request.get(check_email_endpoint + email)
        return data.json()
    except Exception as Error:
        raise Error

def check_nick(nick):
    # Checks if an nick is available

    try:
        data = request.get(check_nick_endpoint + nick)
        return data.json()
    except Exception as Error:
        raise Error